@@ -1,4 +1,4 @@
-from .openapi_client import FindingsApi, ApiClient, ChartsApi, AttachmentsApi, SchemasApi, SecurityApi, ExportApi
+from .openapi_client import FindingsApi, ApiClient, ChartsApi, AttachmentsApi, SchemasApi, TenantsApi, ExportApi
 from . import Configuration
 
 
@@ -43,5 +43,5 @@ class Client():
         return SchemasApi(self.__configured_api_client)
 
     @property
-    def security(self):
-        return SecurityApi(self.__configured_api_client)
+    def tenants(self):
+        return TenantsApi(self.__configured_api_client)
